Utils Module
============

This module contains utility functions.

Progress
--------

.. automodule:: fmusvid.utils.progress
   :members:
   :undoc-members:

Benchmark
---------

.. automodule:: fmusvid.utils.benchmark
   :members:
   :undoc-members:

Optimization
------------

.. automodule:: fmusvid.utils.optimization
   :members:
   :undoc-members:

Quality
-------

.. automodule:: fmusvid.utils.quality
   :members:
   :undoc-members:
